@@ -15,10 +15,9 @@ use rustyline_derive::Helper;
 use std::borrow::Cow;
 use std::fs::File;
 use std::io;
-use std::io::{Read, Write};
+use std::io::Read;
 use sys_locale::get_locale;
 use yozuk::Yozuk;
-use yozuk_sdk::model::*;
 use yozuk_sdk::prelude::*;
 
 mod args;
@@ -55,21 +54,11 @@ impl App {
             ..Default::default()
         };
 
-        let zuk = Yozuk::builder()
-            .set_config(config)
-            .set_i18n(i18n)
-            .build(ModelSet::from_data(yozuk_bundle::MODEL_DATA)?);
-
+        let zuk = Yozuk::builder().set_config(config).set_i18n(i18n).build();
         Ok(Self { args, zuk })
     }
 
     fn run(self) -> Result<()> {
-        if let Some(dump_dst) = self.args.dump_model {
-            let mut out = File::create(dump_dst)?;
-            out.write_all(yozuk_bundle::MODEL_DATA)?;
-            return Ok(());
-        }
-
         let stdin = io::stdin();
         let mut streams = vec![];
         if !stdin.is_tty() {
